import string
import random

INT_UPPER_BOUND = 10000

def random_list(type, count: int) -> list:
    
    if type == str:
        return random_string_list(count)
    elif type == int:
        return random_int_list(count)


    raise NotImplementedError(f"The type ({type}) is not implemented")


def random_string(count: int = 10, chars = string.ascii_uppercase + string.ascii_lowercase + string.digits):
    return ''.join(random.choice(chars) for _ in range(count))

def random_string_list(count: int) -> list[str]:
    return [random_string() for _ in range(count)]

def random_int_list(count: int, upper_bound: int = INT_UPPER_BOUND) -> list[int]:
    return [random.randint(0, upper_bound) for _ in range(count)]



import sys
import os

def project_root_path():
    """
    Returns the directory that contains the __main__ module
    """
    main_module = sys.modules['__main__']

    if not hasattr(main_module, '__file__'):
        raise Exception(f"The main module does not have the '__file__' attribute")

    return os.path.dirname(os.path.abspath(main_module.__file__))

def build_project_rooted_path(*args):
    """
    Creates a path using the components provided that is rooted at the 
    directory containing the __main__ module that (possibly indirectly)
    called this function
    """
    return os.path.join(
        project_root_path(),
        *args
    )